@@ -772,7 +772,8 @@ report.ARIMA <- function(object, ...) {
 #'
 #' Produces forecasts from a trained model.
 #'
-#' @inheritParams fabletools::forecast
+#' @inheritParams generics::forecast
+#' @param new_data A tsibble containing the time points and exogenous regressors to produce forecasts for.
 #' @param specials (passed by [`fabletools::forecast.mdl_df()`]).
 #' @param bootstrap If `TRUE`, then forecast distributions are computed using simulation with resampled errors.
 #' @param times The number of sample paths to use in estimating the forecast distribution when `bootstrap = TRUE`.
@@ -891,9 +892,9 @@ generate.ARIMA <- function(x, new_data, specials, bootstrap = FALSE, ...){
   
   new_data <- transmute(
     group_by_key(new_data), 
-    ".sim" := conditional_arima_sim(x$model, x$est$.regression_resid, !!sym(".innov"))
+    ".sim" := conditional_arima_sim(!!x$model, !!x$est$.regression_resid, !!sym(".innov"))
   )
-  mutate(dplyr::ungroup(new_data), ".sim" := as.numeric(!!sym(".sim") + xm))
+  mutate(dplyr::ungroup(new_data), ".sim" := as.numeric(!!sym(".sim") + !!xm))
 }
 
 # Version of stats::arima.sim which conditions on past observations
